@@ -22,6 +22,7 @@ import logging
 import multiprocessing
 import os
 import pwd
+import shutil
 import signal
 import subprocess
 import tarfile
@@ -37,7 +38,8 @@ from tenacity.wait import wait_fixed
 from tripleoclient.constants import (DEFAULT_HEAT_CONTAINER,
                                      DEFAULT_HEAT_API_CONTAINER,
                                      DEFAULT_HEAT_ENGINE_CONTAINER,
-                                     DEFAULT_TEMPLATES_DIR)
+                                     DEFAULT_TEMPLATES_DIR,
+                                     EPHEMERAL_HEAT_POD_NAME)
 from tripleoclient.exceptions import HeatPodMessageQueueException
 
 log = logging.getLogger(__name__)
@@ -147,38 +149,33 @@ class HeatBaseLauncher(object):
         self.skip_heat_pull = skip_heat_pull
         self.zipped_db_suffix = '.tar.bzip2'
         self.log_dir = os.path.join(self.heat_dir, 'log')
+        self.use_tmp_dir = use_tmp_dir
 
-        if os.path.isdir(self.heat_dir):
-            if use_root:
-                # This one may fail but it's just cleanup.
-                p = subprocess.Popen(['umount', self.heat_dir],
-                                     stdout=subprocess.PIPE,
-                                     stderr=subprocess.PIPE,
-                                     universal_newlines=True)
-                cmd_stdout, cmd_stderr = p.communicate()
-                retval = p.returncode
-                if retval != 0:
-                    log.info('Cleanup unmount of %s failed (probably because '
-                             'it was not mounted): %s' %
-                             (self.heat_dir, cmd_stderr))
-                else:
-                    log.info('umount of %s success' % (self.heat_dir))
-        else:
+        if not os.path.isdir(self.heat_dir):
             # Create the directory if it doesn't exist.
             try:
-                os.makedirs(self.heat_dir, mode=0o700)
+                os.makedirs(self.heat_dir, mode=0o755)
             except Exception as e:
                 log.error('Creating temp directory "%s" failed: %s' %
                           (self.heat_dir, e))
                 raise Exception('Could not create temp directory %s: %s' %
                                 (self.heat_dir, e))
 
+        if self.use_tmp_dir:
+            self.install_dir = tempfile.mkdtemp(
+                prefix='%s/tripleo_deploy-' % self.heat_dir)
+        else:
+            self.install_dir = self.heat_dir
+
         if use_root:
+            self.umount_install_dir()
+
+        if use_root and use_tmp_dir:
             # As an optimization we mount the tmp directory in a tmpfs (in
             # memory) filesystem.  Depending on your system this can cut the
             # heat deployment times by half.
             p = subprocess.Popen(['mount', '-t', 'tmpfs', '-o', 'size=500M',
-                                  'tmpfs', self.heat_dir],
+                                  'tmpfs', self.install_dir],
                                  stdout=subprocess.PIPE,
                                  stderr=subprocess.PIPE,
                                  universal_newlines=True)
@@ -191,20 +188,12 @@ class HeatBaseLauncher(object):
                             'database %s: %s' %
                             (self.heat_dir, cmd_stderr))
 
-        if use_tmp_dir:
-            self.install_dir = tempfile.mkdtemp(
-                prefix='%s/undercloud_deploy-' % self.heat_dir)
-        else:
-            self.install_dir = self.heat_dir
-
         self.log_file = self._get_log_file_path()
         self.sql_db = os.path.join(self.install_dir, 'heat.sqlite')
         self.config_file = os.path.join(self.install_dir, 'heat.conf')
         self.paste_file = os.path.join(self.install_dir, 'api-paste.ini')
         self.token_file = os.path.join(self.install_dir, 'token_file.json')
 
-        self.policy_file = os.path.join(os.path.dirname(__file__),
-                                        'noauth_policy.json')
         self.user = user
         self._write_fake_keystone_token(self.api_port, self.token_file)
         self._write_heat_config()
@@ -220,6 +209,21 @@ class HeatBaseLauncher(object):
             self.kill_heat(None)
             self.rm_heat()
 
+    def umount_install_dir(self):
+        # This one may fail but it's just cleanup.
+        p = subprocess.Popen(['umount', self.install_dir],
+                             stdout=subprocess.PIPE,
+                             stderr=subprocess.PIPE,
+                             universal_newlines=True)
+        cmd_stdout, cmd_stderr = p.communicate()
+        retval = p.returncode
+        if retval != 0:
+            log.info('Cleanup unmount of %s failed (probably because '
+                     'it was not mounted): %s' %
+                     (self.heat_dir, cmd_stderr))
+        else:
+            log.info('umount of %s success' % (self.heat_dir))
+
     def _get_log_file_path(self):
         return os.path.join(self.install_dir, 'heat.log')
 
@@ -259,14 +263,11 @@ connection = sqlite:///%(sqlite_db)s.db
 flavor = noauth
 api_paste_config = api-paste.ini
 
-[oslo_policy]
-policy_file = %(policy_file)s
-
 [yaql]
 memory_quota=900000
 limit_iterators=9000
         ''' % {'sqlite_db': self.sql_db, 'log_file': self.log_file,
-               'api_port': self.api_port, 'policy_file': self.policy_file,
+               'api_port': self.api_port,
                'token_file': self.token_file}
 
         with open(self.config_file, 'w') as temp_file:
@@ -363,8 +364,6 @@ class HeatContainerLauncher(HeatBaseLauncher):
                 'conf': self.paste_file},
             '--volume', '%(inst_tmp)s:%(inst_tmp)s:Z' % {'inst_tmp':
                                                          self.install_dir},
-            '--volume', '%(pfile)s:%(pfile)s:ro' % {'pfile':
-                                                    self.policy_file},
             self.all_container_image, 'heat-all'
         ]
         log.debug(' '.join(cmd))
@@ -436,12 +435,19 @@ class HeatNativeLauncher(HeatBaseLauncher):
     def launch_heat(self):
         os.execvp('heat-all', ['heat-all', '--config-file', self.config_file])
 
-    def heat_db_sync(self):
+    def heat_db_sync(self, restore_db=False):
         subprocess.check_call(['heat-manage', '--config-file',
                                self.config_file, 'db_sync'])
 
     def kill_heat(self, pid):
         os.kill(pid, signal.SIGKILL)
+        if self.use_tmp_dir:
+            shutil.copytree(
+                self.install_dir,
+                os.path.join(self.heat_dir,
+                             'tripleo_deploy-%s' % self.timestamp))
+        self.umount_install_dir()
+        shutil.rmtree(self.install_dir)
 
 
 class HeatPodLauncher(HeatContainerLauncher):
@@ -478,7 +484,7 @@ class HeatPodLauncher(HeatContainerLauncher):
     def get_pod_state(self):
         inspect = subprocess.run([
             'sudo', 'podman', 'pod', 'inspect', '--format',
-            '"{{.State}}"', 'ephemeral-heat'],
+            '"{{.State}}"', EPHEMERAL_HEAT_POD_NAME],
             check=False,
             stdout=subprocess.PIPE,
             stderr=subprocess.STDOUT)
@@ -486,7 +492,8 @@ class HeatPodLauncher(HeatContainerLauncher):
 
     def launch_heat(self):
         if "Running" in self.get_pod_state():
-            log.info("ephemeral-heat pod already running, skipping launch")
+            log.info("%s pod already running, skipping launch",
+                     EPHEMERAL_HEAT_POD_NAME)
             return
         self._write_heat_pod()
         subprocess.check_call([
@@ -570,7 +577,7 @@ class HeatPodLauncher(HeatContainerLauncher):
     def pod_exists(self):
         try:
             subprocess.check_call(
-                ['sudo', 'podman', 'pod', 'inspect', 'ephemeral-heat'],
+                ['sudo', 'podman', 'pod', 'inspect', EPHEMERAL_HEAT_POD_NAME],
                 stdout=subprocess.DEVNULL,
                 stderr=subprocess.DEVNULL)
             return True
@@ -593,9 +600,10 @@ class HeatPodLauncher(HeatContainerLauncher):
             except subprocess.CalledProcessError:
                 pass
         if self.pod_exists():
-            log.info("Removing pod: ephemeral-heat")
+            log.info("Removing pod: %s", EPHEMERAL_HEAT_POD_NAME)
             subprocess.call([
-                'sudo', 'podman', 'pod', 'rm', '-f', 'ephemeral-heat'
+                'sudo', 'podman', 'pod', 'rm', '-f',
+                EPHEMERAL_HEAT_POD_NAME
             ])
         config = self._read_heat_config()
         log_file_path = os.path.join(self.log_dir,
@@ -605,11 +613,12 @@ class HeatPodLauncher(HeatContainerLauncher):
 
     def stop_heat(self):
         if self.pod_exists() and self.get_pod_state() != 'Exited':
-            log.info("Stopping pod: ephemeral-heat")
+            log.info("Stopping pod: %s", EPHEMERAL_HEAT_POD_NAME)
             subprocess.check_call([
-                'sudo', 'podman', 'pod', 'stop', 'ephemeral-heat'
+                'sudo', 'podman', 'pod', 'stop',
+                EPHEMERAL_HEAT_POD_NAME
             ])
-            log.info("Stopped pod: ephemeral-heat")
+            log.info("Stopped pod: %s", EPHEMERAL_HEAT_POD_NAME)
 
     def check_message_bus(self):
         log.info("Checking that message bus (rabbitmq) is up")
@@ -650,13 +659,14 @@ class HeatPodLauncher(HeatContainerLauncher):
 
     def kill_heat(self, pid):
         if self.pod_exists():
-            log.info("Killing pod: ephemeral-heat")
+            log.info("Killing pod: %s", EPHEMERAL_HEAT_POD_NAME)
             subprocess.call([
-                'sudo', 'podman', 'pod', 'kill', 'ephemeral-heat'
+                'sudo', 'podman', 'pod', 'kill',
+                EPHEMERAL_HEAT_POD_NAME
             ])
-            log.info("Killed pod: ephemeral-heat")
+            log.info("Killed pod: %s", EPHEMERAL_HEAT_POD_NAME)
         else:
-            log.info("Pod does not exist: ephemeral-heat")
+            log.info("Pod does not exist: %s", EPHEMERAL_HEAT_POD_NAME)
 
     def _decode(self, encoded):
         if not encoded:
@@ -702,11 +712,11 @@ class HeatPodLauncher(HeatContainerLauncher):
            stop=(stop_after_delay(10) | stop_after_attempt(10)),
            wait=wait_fixed(0.5))
     def wait_for_message_queue(self):
+        queue_name = 'engine.' + EPHEMERAL_HEAT_POD_NAME
         output = subprocess.check_output([
-            'sudo', 'podman', 'exec',  'rabbitmq',
-            'rabbitmqctl', 'list_queues'
-        ])
-        if 'heat' not in str(output):
+            'sudo', 'podman', 'exec', 'rabbitmq',
+            'rabbitmqctl', 'list_queues'])
+        if str(output).count(queue_name) < 1:
             msg = "Message queue for ephemeral heat not created in time."
             raise HeatPodMessageQueueException(msg)
 
@@ -720,7 +730,7 @@ class HeatPodLauncher(HeatContainerLauncher):
 
     def _write_heat_config(self):
         heat_config_tmpl_path = os.path.join(DEFAULT_TEMPLATES_DIR,
-                                             "ephemeral-heat",
+                                             EPHEMERAL_HEAT_POD_NAME,
                                              "heat.conf.j2")
         with open(heat_config_tmpl_path) as tmpl:
             heat_config_tmpl = jinja2.Template(tmpl.read())
@@ -739,7 +749,7 @@ class HeatPodLauncher(HeatContainerLauncher):
 
     def _write_heat_pod(self):
         heat_pod_tmpl_path = os.path.join(DEFAULT_TEMPLATES_DIR,
-                                          "ephemeral-heat",
+                                          EPHEMERAL_HEAT_POD_NAME,
                                           "heat-pod.yaml.j2")
         with open(heat_pod_tmpl_path) as tmpl:
             heat_pod_tmpl = jinja2.Template(tmpl.read())
@@ -747,11 +757,11 @@ class HeatPodLauncher(HeatContainerLauncher):
         pod_vars = {
             "install_dir": self.install_dir,
             "heat_dir": self.heat_dir,
-            "policy_file": self.policy_file,
             "ctlplane_ip": self.host,
             "api_port": self.api_port,
             "api_image": self.api_container_image,
             "engine_image": self.engine_container_image,
+            "heat_pod_name": EPHEMERAL_HEAT_POD_NAME
         }
         heat_pod = heat_pod_tmpl.render(**pod_vars)
 
