@@ -48,7 +48,7 @@ class TestOvercloudExternalUpgradeRun(fakes.TestOvercloudExternalUpgradeRun):
                 autospec=True)
     @mock.patch('os.path.expanduser')
     @mock.patch('oslo_concurrency.processutils.execute')
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_upgrade_with_user_and_tags(self, mock_open, mock_execute,
                                         mock_expanduser, update_ansible,
                                         mock_run, mock_run_prepare):
@@ -75,7 +75,7 @@ class TestOvercloudExternalUpgradeRun(fakes.TestOvercloudExternalUpgradeRun):
                 autospec=True)
     @mock.patch('os.path.expanduser')
     @mock.patch('oslo_concurrency.processutils.execute')
-    @mock.patch('six.moves.builtins.open')
+    @mock.patch('builtins.open')
     def test_upgrade_with_user_and_extra_vars(self, mock_open, mock_execute,
                                               mock_expanduser, update_ansible,
                                               mock_run, mock_run_prepare):
