@@ -60,7 +60,7 @@ class UpdatePrepare(DeployOvercloud):
         # In case of update and upgrade we need to force the
         # config_download to false. The heat stack update will be performed
         # by DeployOvercloud class but skipping the config download part.
-        parsed_args.stack_only = True
+        parsed_args.config_download = False
 
         # Add the update-prepare.yaml environment to set noops etc
         templates_dir = (parsed_args.templates or
@@ -130,11 +130,6 @@ class UpdateRun(command.Command):
                             default=utils.env('OVERCLOUD_STACK_NAME',
                                               default='overcloud')
                             )
-        parser.add_argument('--no-workflow', dest='no_workflow',
-                            action='store_true',
-                            default=True,
-                            help=_('This option no longer has any effect.')
-                            )
         parser.add_argument(
             '--tags',
             action='store',
@@ -217,3 +212,55 @@ class UpdateRun(command.Command):
             }
         )
         self.log.info("Completed Minor Update Run.")
+
+
+class UpdateConverge(DeployOvercloud):
+    """Converge the update on Overcloud nodes.
+    This restores the plan and stack so that normal deployment
+    workflow is back in place.
+    """
+    log = logging.getLogger(__name__ + ".UpdateConverge")
+
+    def get_parser(self, prog_name):
+        parser = super(UpdateConverge, self).get_parser(prog_name)
+
+        return parser
+
+    def take_action(self, parsed_args):
+        logging.register_options(CONF)
+        logging.setup(CONF, '')
+        self.log.debug("take_action(%s)" % parsed_args)
+        oooutils.ensure_run_as_normal_user()
+
+        if (not parsed_args.yes
+            and not oooutils.prompt_user_for_confirmation(
+                    constants.UPDATE_PROMPT, self.log)):
+            raise OvercloudUpdateNotConfirmed(constants.UPDATE_NO)
+
+        ansible_dir = os.path.join(oooutils.get_default_working_dir(
+                                        parsed_args.stack
+                                        ),
+                                   'config-download',
+                                   parsed_args.stack)
+
+        inventory = os.path.join(ansible_dir,
+                                 'tripleo-ansible-inventory.yaml')
+
+        ansible_cfg = os.path.join(ansible_dir, 'ansible.cfg')
+        key_file = oooutils.get_key(parsed_args.stack)
+
+        oooutils.run_ansible_playbook(
+            playbook='deploy_steps_playbook.yaml',
+            inventory=inventory,
+            workdir=ansible_dir,
+            playbook_dir=ansible_dir,
+            ansible_cfg=ansible_cfg,
+            ssh_user='tripleo-admin',
+            reproduce_command=True,
+            forks=parsed_args.ansible_forks,
+            extra_env_variables={
+                "ANSIBLE_BECOME": True,
+                "ANSIBLE_PRIVATE_KEY_FILE": key_file
+            }
+        )
+        self.log.info("Completed Minor Update Converge.")
