@@ -71,9 +71,9 @@ class UpgradePrepare(DeployOvercloud):
         clients = self.app.client_manager
 
         # In case of update and upgrade we need to force the
-        # stack_only to true. The heat stack update will be performed
+        # config_download to false. The heat stack update will be performed
         # by DeployOvercloud class but skipping the config download part.
-        parsed_args.stack_only = True
+        parsed_args.config_download = False
         # Add the template attribute environment to set noops etc
         templates_dir = (parsed_args.templates or
                          constants.TRIPLEO_HEAT_TEMPLATES)
@@ -187,11 +187,6 @@ class UpgradeRun(command.Command):
                             default=utils.env('OVERCLOUD_STACK_NAME',
                                               default='overcloud')
                             )
-        parser.add_argument('--no-workflow', dest='no_workflow',
-                            action='store_true',
-                            default=True,
-                            help=_('This option no longer has any effect.')
-                            )
         parser.add_argument('-y', '--yes', default=False,
                             action='store_true',
                             help=_("Use -y or --yes to skip the confirmation "
@@ -228,14 +223,16 @@ class UpgradeRun(command.Command):
             playbook = parsed_args.playbook
 
         _, ansible_dir = self.get_ansible_key_and_dir(
-            no_workflow=parsed_args.no_workflow,
             stack=parsed_args.stack,
             orchestration=self.app.client_manager.orchestration
         )
         deployment.config_download(
             log=self.log,
             clients=self.app.client_manager,
-            stack_name=parsed_args.stack,
+            stack=oooutils.get_stack(
+                self.app.client_manager.orchestration,
+                parsed_args.stack
+            ),
             output_dir=ansible_dir,
             verbosity=oooutils.playbook_verbosity(self=self),
             ansible_playbook_name=playbook,
