@@ -14,13 +14,13 @@
 #
 
 import argparse
+import configparser
 import json
 import logging
 import netaddr
 import os
 import pwd
 import shutil
-import six
 import subprocess
 import sys
 import tempfile
@@ -31,7 +31,6 @@ import yaml
 from cliff import command
 from heatclient.common import template_utils
 from osc_lib.i18n import _
-from six.moves import configparser
 
 from tripleoclient import constants
 from tripleoclient import exceptions
@@ -188,8 +187,7 @@ class Deploy(command.Command):
         if not parsed_args.networks_file:
             return os.path.join(parsed_args.templates,
                                 constants.STANDALONE_NETWORKS_FILE)
-        else:
-            return parsed_args.networks_file
+        return parsed_args.networks_file
 
     def _get_primary_role_name(self, roles_file_path, templates):
         """Return the primary role name"""
@@ -276,6 +274,8 @@ class Deploy(command.Command):
 
     def _update_passwords_env(self, output_dir, user, upgrade=None,
                               passwords=None, stack_name='undercloud'):
+        old_pw_file = os.path.join(constants.CLOUD_HOME_DIR,
+                                   'tripleo-' + stack_name + '-passwords.yaml')
         pw_file = os.path.join(output_dir,
                                'tripleo-' + stack_name + '-passwords.yaml')
         undercloud_pw_file = os.path.join(constants.CLOUD_HOME_DIR,
@@ -286,10 +286,22 @@ class Deploy(command.Command):
         stack_env = {'parameter_defaults': {}}
         stack_env['parameter_defaults'] = password_utils.generate_passwords(
             stack_env=stack_env)
+        # Check for the existence of a passwords file in the old location.
+        if os.path.exists(old_pw_file):
+            self.log.warning("Migrating {} to {}.".format(
+                old_pw_file, pw_file))
+            try:
+                os.rename(old_pw_file, pw_file)
+            except Exception as e:
+                self.log.error("Error moving {} to {}".format(
+                    old_pw_file, pw_file))
+                self.log.error(e)
+                raise e
         if os.path.exists(pw_file):
             with open(pw_file) as pf:
                 stack_env['parameter_defaults'].update(
                     yaml.safe_load(pf.read())['parameter_defaults'])
+            self.log.warning("Reading passwords from %s" % pw_file)
 
         if upgrade:
             # Getting passwords that were managed by instack-undercloud so
@@ -449,19 +461,27 @@ class Deploy(command.Command):
             pid, ret = os.waitpid(self.heat_pid, 0)
             self.heat_pid = None
 
-    def _launch_heat(self, parsed_args):
+    def _launch_heat(self, parsed_args, output_dir):
         # we do this as root to chown config files properly for docker, etc.
+        heat_launcher_path = os.path.join(output_dir, 'heat_launcher')
+
+        if parsed_args.heat_user:
+            heat_user = parsed_args.heat_user
+        else:
+            heat_user = parsed_args.deployment_user
+
         if parsed_args.heat_native is not None and \
                 parsed_args.heat_native.lower() == "false":
             self.heat_launch = heat_launcher.HeatContainerLauncher(
-                parsed_args.heat_api_port,
-                parsed_args.heat_container_image,
-                parsed_args.heat_user)
+                api_port=parsed_args.heat_api_port,
+                all_container_image=parsed_args.heat_container_image,
+                user=heat_user,
+                heat_dir=heat_launcher_path)
         else:
             self.heat_launch = heat_launcher.HeatNativeLauncher(
-                parsed_args.heat_api_port,
-                parsed_args.heat_container_image,
-                parsed_args.heat_user,
+                api_port=parsed_args.heat_api_port,
+                user=heat_user,
+                heat_dir=heat_launcher_path,
                 use_root=True)
 
         # NOTE(dprince): we launch heat with fork exec because
@@ -474,12 +494,12 @@ class Deploy(command.Command):
             if parsed_args.heat_native is not None and \
                     parsed_args.heat_native.lower() == "true":
                 try:
-                    uid = pwd.getpwnam(parsed_args.heat_user).pw_uid
-                    gid = pwd.getpwnam(parsed_args.heat_user).pw_gid
+                    uid = pwd.getpwnam(heat_user).pw_uid
+                    gid = pwd.getpwnam(heat_user).pw_gid
                 except KeyError:
                     msg = _(
                         "Please create a %s user account before "
-                        "proceeding.") % parsed_args.heat_user
+                        "proceeding.") % heat_user
                     self.log.error(msg)
                     raise exceptions.DeploymentError(msg)
                 os.setgid(gid)
@@ -591,7 +611,8 @@ class Deploy(command.Command):
 
         # generate jinja templates by its work dir location
         self.log.debug(_("Using roles file %s") % roles_file_path)
-        utils.jinja_render_files(self.log, parsed_args.templates,
+        utils.jinja_render_files(self.log,
+                                 templates=parsed_args.templates,
                                  working_dir=self.tht_render,
                                  roles_file=roles_file_path,
                                  networks_file=networks_file_path,
@@ -745,33 +766,12 @@ class Deploy(command.Command):
 
         roles_data = utils.fetch_roles_file(
             roles_file_path, parsed_args.templates)
-        to_remove = set()
-        for key, value in env.get('resource_registry', {}).items():
-            if (key.startswith('OS::TripleO::Services::') and
-                    value == 'OS::Heat::None'):
-                to_remove.add(key)
-        if to_remove:
-            for role in roles_data:
-                for service in to_remove:
-                    try:
-                        role.get('ServicesDefault', []).remove(service)
-                    except ValueError:
-                        pass
-            self.log.info('Removing unused services, updating roles')
-            # This will clean up the directory and set it up again
-            self.tht_render = None
-            self._populate_templates_dir(parsed_args.templates,
-                                         parsed_args.stack.lower())
-            roles_file_path = os.path.join(
-                self.tht_render, 'roles-data-override.yaml')
-            with open(roles_file_path, "w") as f:
-                f.write(yaml.safe_dump(roles_data))
-            # Redo the dance
-            environments = self._setup_heat_environments(
-                roles_file_path, networks_file_path, parsed_args)
-            env_files, env = utils.process_multiple_environments(
-                environments, self.tht_render, parsed_args.templates,
-                cleanup=parsed_args.cleanup)
+
+        parameter_defaults = env.get('parameter_defaults', {})
+        enabled_service_map = kolla_builder.get_enabled_services(
+            env, roles_data)
+        if enabled_service_map:
+            parameter_defaults.update(enabled_service_map)
 
         if not parsed_args.disable_container_prepare:
             self._prepare_container_images(env, roles_data)
@@ -822,9 +822,7 @@ class Deploy(command.Command):
             stack_name))
         # python output buffering is making this seem to take forever..
         sys.stdout.flush()
-        stack_config.write_config(stack_config.fetch_config(stack_name),
-                                  stack_name,
-                                  self.tmp_ansible_dir)
+        stack_config.download_config(stack_name, self.tmp_ansible_dir)
 
         inventory = TripleoInventory(
             hclient=client,
@@ -844,6 +842,9 @@ class Deploy(command.Command):
         shutil.copyfile(inv_path,
                         os.path.join(self.output_dir,
                                      constants.TRIPLEO_STATIC_INVENTORY))
+        # copy inventory file to Runner friendly path
+        shutil.copyfile(inv_path, os.path.join(self.tmp_ansible_dir,
+                                               'inventory', 'tripleo'))
 
         self.log.info(_('** Downloaded {0} ansible to {1} **').format(
                       stack_name, self.tmp_ansible_dir))
@@ -899,11 +900,6 @@ class Deploy(command.Command):
             help=_("The directory containing the Heat templates to deploy"),
             default=constants.TRIPLEO_HEAT_TEMPLATES
         )
-        parser.add_argument('--standalone', default=False, action='store_true',
-                            help=_("DEPRECATED. The --standalone argument is "
-                                   "now deprecated. Standalone deployments "
-                                   "can now be run without passing "
-                                   "--standalone. "))
         parser.add_argument('--upgrade', default=False, action='store_true',
                             help=_("Upgrade an existing deployment."))
         parser.add_argument('-y', '--yes', default=False, action='store_true',
@@ -968,9 +964,8 @@ class Deploy(command.Command):
         parser.add_argument(
             '--heat-user', metavar='<HEAT_USER>',
             dest='heat_user',
-            default='heat',
             help=_('User to execute the non-privileged heat-all process. '
-                   'Defaults to heat.')
+                   'Defaults to the value of --deployment-user.')
         )
         # TODO(cjeanner) drop that once using oslo.privsep
         parser.add_argument(
@@ -1099,6 +1094,13 @@ class Deploy(command.Command):
                    'the container parameters configured, the deployment '
                    'action may fail.')
         )
+        parser.add_argument(
+            '--reproduce-command',
+            action='store_true',
+            default=False,
+            help=_('Create a reproducer command with ansible command'
+                   'line and all environments variables.')
+        )
 
         stack_action_group = parser.add_mutually_exclusive_group()
 
@@ -1254,7 +1256,7 @@ class Deploy(command.Command):
             self._set_stack_action(parsed_args)
 
             # Launch heat.
-            orchestration_client = self._launch_heat(parsed_args)
+            orchestration_client = self._launch_heat(parsed_args, output_dir)
             # Wait for heat to be ready.
             utils.wait_api_port_ready(parsed_args.heat_api_port)
             # Deploy TripleO Heat templates.
@@ -1336,12 +1338,13 @@ class Deploy(command.Command):
                         utils.run_ansible_playbook(
                             inventory=os.path.join(
                                 self.ansible_dir,
-                                'inventory.yaml'
+                                'inventory'
                             ),
                             workdir=self.ansible_dir,
                             verbosity=utils.playbook_verbosity(self=self),
                             extra_env_variables=extra_env_var,
                             forks=parsed_args.ansible_forks,
+                            reproduce_command=parsed_args.reproduce_command,
                             **operation)
             is_complete = True
         finally:
@@ -1429,9 +1432,9 @@ class Deploy(command.Command):
         try:
             self._standalone_deploy(parsed_args)
         except Exception as ex:
-            self.log.error("Exception: %s" % six.text_type(ex))
+            self.log.error("Exception: %s" % str(ex))
             self.log.error(traceback.print_exc())
-            raise exceptions.DeploymentError(six.text_type(ex))
+            raise exceptions.DeploymentError(str(ex))
         finally:
             # Copy clouds.yaml from /etc/openstack so credentials can be
             # read by the deployment user and not only root.
