@@ -73,7 +73,11 @@ class ImportNode(command.Command):
                             choices=['local', 'netboot'], default=None,
                             help=_('Whether to set instances for booting from'
                                    ' local hard drive (local) or network '
-                                   ' (netboot).'))
+                                   ' (netboot)'))
+        parser.add_argument('--boot-mode',
+                            choices=['uefi', 'bios'], default=None,
+                            help=_('Whether to set the boot mode to UEFI '
+                                   '(uefi) or legacy BIOS (bios)'))
         parser.add_argument("--http-boot",
                             default=os.environ.get(
                                 'HTTP_BOOT',
@@ -105,7 +109,8 @@ class ImportNode(command.Command):
         nodes = baremetal.register_or_update(
             self.app.client_manager,
             nodes_json=nodes_config,
-            instance_boot_option=parsed_args.instance_boot_option
+            instance_boot_option=parsed_args.instance_boot_option,
+            boot_mode=parsed_args.boot_mode
         )
 
         nodes_uuids = [node.uuid for node in nodes]
@@ -207,8 +212,8 @@ class IntrospectNode(command.Command):
         if parsed_args.provide:
             if parsed_args.node_uuids:
                 baremetal.provide(
-                    self.app.client_manager,
                     node_uuids=parsed_args.node_uuids,
+                    verbosity=oooutils.playbook_verbosity(self=self)
                 )
             else:
                 baremetal.provide_manageable_nodes(
@@ -254,7 +259,9 @@ class ProvisionNode(command.Command):
                             help=_('Number of seconds to wait for the node '
                                    'provision to complete. (default=3600)'))
         parser.add_argument('--network-ports',
-                            help=_('Enable provisioning of network ports'),
+                            help=_('DEPRECATED! Network ports will always be '
+                                   'provisioned.\n'
+                                   'Enable provisioning of network ports'),
                             default=False,
                             action="store_true")
         parser.add_argument('--network-config',
@@ -262,6 +269,10 @@ class ProvisionNode(command.Command):
                                    'nodes. (Implies "--network-ports")'),
                             default=False,
                             action="store_true")
+        parser.add_argument('--templates',
+                            help=_("The directory containing the Heat "
+                                   "templates to deploy"),
+                            default=constants.TRIPLEO_HEAT_TEMPLATES)
         parser.add_argument(
             '--working-dir', action='store',
             help=_('The working directory for the deployment where all '
@@ -282,6 +293,11 @@ class ProvisionNode(command.Command):
     def take_action(self, parsed_args):
         self.log.debug("take_action(%s)" % parsed_args)
 
+        if parsed_args.network_ports:
+            self.log.warning('DEPRECATED option "--network-ports" detected. '
+                             'This option is no longer used, network ports '
+                             'are always managed.')
+
         if not parsed_args.working_dir:
             working_dir = oooutils.get_default_working_dir(
                 parsed_args.stack)
@@ -290,9 +306,12 @@ class ProvisionNode(command.Command):
         oooutils.makedirs(working_dir)
 
         roles_file_path = os.path.abspath(parsed_args.input)
+        roles_file_dir = os.path.dirname(roles_file_path)
         with open(roles_file_path, 'r') as fp:
             roles = yaml.safe_load(fp)
 
+        oooutils.validate_roles_playbooks(roles_file_dir, roles)
+
         key = self.get_key_pair(parsed_args)
         with open('{}.pub'.format(key), 'rt') as fp:
             ssh_key = fp.read()
@@ -308,9 +327,10 @@ class ProvisionNode(command.Command):
             "ssh_user_name": parsed_args.overcloud_ssh_user,
             "node_timeout": parsed_args.timeout,
             "concurrency": parsed_args.concurrency,
-            "manage_network_ports": (parsed_args.network_ports
-                                     or parsed_args.network_config),
-            "working_dir": working_dir
+            "manage_network_ports": True,
+            "configure_networking": parsed_args.network_config,
+            "working_dir": working_dir,
+            "templates": parsed_args.templates,
         }
 
         with oooutils.TempDirs() as tmp:
@@ -322,78 +342,11 @@ class ProvisionNode(command.Command):
                 verbosity=oooutils.playbook_verbosity(self=self),
                 extra_vars=extra_vars,
             )
+        oooutils.run_role_playbooks(self, working_dir, roles_file_dir,
+                                    roles, parsed_args.network_config)
 
-        if parsed_args.network_ports or parsed_args.network_config:
-            roles_file_dir = os.path.dirname(roles_file_path)
-            inventory_file = os.path.join(working_dir,
-                                          'tripleo-ansible-inventory.yaml')
-            with open(inventory_file, 'r') as f:
-                inventory = yaml.safe_load(f.read())
-
-            # Pre-Network Config
-            for role in roles:
-                for playbook in role.get('ansible_playbooks', []):
-                    if not playbook.get('pre_network'):
-                        continue
-
-                    if os.path.isabs(playbook['playbook']):
-                        playbook_path = playbook['playbook']
-                    else:
-                        # Load for playbook relative to the roles file
-                        playbook_path = os.path.join(roles_file_dir,
-                                                     playbook['playbook'])
-
-                    self._validate_playbook(playbook_path)
-                    playbook_dir = os.path.basename(playbook_path)
-
-                    with oooutils.TempDirs() as tmp:
-                        oooutils.run_ansible_playbook(
-                            playbook=playbook_path,
-                            inventory=inventory,
-                            workdir=tmp,
-                            playbook_dir=playbook_dir,
-                            verbosity=oooutils.playbook_verbosity(self=self),
-                            limit_hosts=role['name'],
-                            extra_vars=playbook.get('extra_vars', {})
-                        )
-
-            # Network Config
-            if parsed_args.network_config:
-                with oooutils.TempDirs() as tmp:
-                    oooutils.run_ansible_playbook(
-                        playbook='cli-overcloud-node-network-config.yaml',
-                        inventory=inventory,
-                        workdir=tmp,
-                        playbook_dir=constants.ANSIBLE_TRIPLEO_PLAYBOOKS,
-                        verbosity=oooutils.playbook_verbosity(self=self),
-                    )
-
-            # Post-Network Config
-            for role in roles:
-                for playbook in role.get('ansible_playbooks', []):
-                    if playbook.get('pre_network'):
-                        continue
-
-                    if os.path.isabs(playbook['playbook']):
-                        playbook_path = playbook['playbook']
-                    else:
-                        # Load for playbook relative to the roles file
-                        playbook_path = os.path.join(roles_file_dir,
-                                                     playbook['playbook'])
-
-                    self._validate_playbook(playbook_path)
-                    playbook_dir = os.path.basename(playbook_path)
-
-                    with oooutils.TempDirs() as tmp:
-                        oooutils.run_ansible_playbook(
-                            playbook=playbook_path,
-                            inventory=inventory,
-                            workdir=tmp,
-                            playbook_dir=playbook_dir,
-                            verbosity=oooutils.playbook_verbosity(self=self),
-                            limit_hosts=role['name'],
-                            extra_vars=playbook.get('extra_vars', {})
-                        )
+        oooutils.copy_to_wd(working_dir, roles_file_path, parsed_args.stack,
+                            'baremetal')
 
         print('Nodes deployed successfully, add %s to your deployment '
               'environment' % parsed_args.output)
@@ -425,7 +378,9 @@ class UnprovisionNode(command.Command):
                             help=_('Configuration file describing the '
                                    'baremetal deployment'))
         parser.add_argument('--network-ports',
-                            help=_('Enable unprovisioning of network ports'),
+                            help=_('DEPRECATED! Network ports will always be '
+                                   'unprovisioned.\n'
+                                   'Enable unprovisioning of network ports'),
                             default=False,
                             action="store_true")
         return parser
@@ -433,6 +388,11 @@ class UnprovisionNode(command.Command):
     def take_action(self, parsed_args):
         self.log.debug("take_action(%s)" % parsed_args)
 
+        if parsed_args.network_ports:
+            self.log.warning('DEPRECATED option "--network-ports" detected. '
+                             'This option is no longer used, network ports '
+                             'are always managed.')
+
         with open(parsed_args.input, 'r') as fp:
             roles = yaml.safe_load(fp)
 
@@ -452,7 +412,7 @@ class UnprovisionNode(command.Command):
                         "all": parsed_args.all,
                         "prompt": True,
                         "unprovision_confirm": unprovision_confirm,
-                        "manage_network_ports": parsed_args.network_ports,
+                        "manage_network_ports": True,
                     }
                 )
                 with open(unprovision_confirm) as f:
